@@ -13,6 +13,8 @@ impl Display for Shell {
             Self::Zsh => "zsh",
             Self::Fish => "fish",
             Self::Elvish => "elvish",
+            Self::Nushell => "nushell",
+            Self::PowerShell => "powershell",
         };
 
         write!(f, "{s}")
@@ -34,6 +36,8 @@ impl Runnable for Input {
             Shell::Zsh => include_str!("../../shell/navi.plugin.zsh"),
             Shell::Fish => include_str!("../../shell/navi.plugin.fish"),
             Shell::Elvish => include_str!("../../shell/navi.plugin.elv"),
+            Shell::Nushell => include_str!("../../shell/navi.plugin.nu"),
+            Shell::PowerShell => include_str!("../../shell/navi.plugin.ps1"),
         };
 
         println!("{content}");
