@@ -11,6 +11,8 @@ pub enum Shell {
     Zsh,
     Fish,
     Elvish,
+    Nushell,
+    PowerShell,
 }
 
 #[derive(Error, Debug)]
