@@ -1,8 +1,8 @@
+use crate::prelude::*;
 pub use env::remove_var as remove;
 pub use env::set_var as set;
 pub use env::var as get;
 use std::env;
-use std::str::FromStr;
 
 pub const PREVIEW_INITIAL_SNIPPET: &str = "NAVI_PREVIEW_INITIAL_SNIPPET";
 pub const PREVIEW_TAGS: &str = "NAVI_PREVIEW_TAGS";
@@ -31,7 +31,7 @@ pub fn must_get(name: &str) -> String {
     if let Ok(v) = env::var(name) {
         v
     } else {
-        panic!("{} not set", name)
+        panic!("{name} not set")
     }
 }
 
